16.107. cdist-type__package_rubygem(7) — cdist 6.5.4 documentation

# 16.107. cdist-type__package_rubygem(7)

## 16.107.1. NAME

cdist-type__package_rubygem - Manage rubygem packages

## 16.107.2. DESCRIPTION

Rubygems is the default package management system for the Ruby programming language.

## 16.107.3. REQUIRED PARAMETERS

None

## 16.107.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present"

## 16.107.5. EXAMPLES

    # Ensure sinatra is installed
    __package_rubygem sinatra --state present

    # Remove package
    __package_rubygem rails --state absent

## 16.107.6. SEE ALSO

cdist-type__package(7)

## 16.107.7. AUTHORS

Chase Allen James <nx-cdist@nu-ex.com>

## 16.107.8. COPYING

Copyright (C) 2011 Chase Allen James. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.